@@ -470,7 +470,7 @@ class TestPoolMaxSize(_TestPoolingBase):
         # The pool acquires its semaphore before attempting to connect; ensure
         # it releases the semaphore on connection failure.
         test_pool = Pool(
-            ('example.com', 27017),
+            ('somedomainthatdoesntexist.org', 27017),
             PoolOptions(
                 max_pool_size=1,
                 connect_timeout=1,
