@@ -26,12 +26,6 @@ except ImportError:
     # Python 2
     from urllib import quote_plus
 
-try:
-    import ipaddress
-    _HAVE_IPADDRESS = True
-except ImportError:
-    _HAVE_IPADDRESS = False
-
 from pymongo import MongoClient, ssl_support
 from pymongo.errors import (ConfigurationError,
                             ConnectionFailure,
@@ -43,7 +37,8 @@ from test import (IntegrationTest,
                   db_pwd,
                   db_user,
                   SkipTest,
-                  unittest)
+                  unittest,
+                  HAVE_IPADDRESS)
 from test.utils import remove_all_users, connected
 
 if HAVE_SSL:
@@ -66,7 +61,7 @@ MONGODB_X509_USERNAME = (
 # Also, make sure you have 'server' as an alias for localhost in /etc/hosts
 #
 # Note: For all replica set tests to pass, the replica set configuration must
-# use 'server' for the hostname of all hosts.
+# use 'localhost' for the hostname of all hosts.
 
 
 class TestClientSSL(unittest.TestCase):
@@ -177,7 +172,6 @@ class TestSSL(IntegrationTest):
         self.assertClientWorks(self.client)
 
     @client_context.require_ssl_certfile
-    @client_context.require_server_resolvable
     def test_ssl_pem_passphrase(self):
         # Expects the server to be running with server.pem and ca.pem
         #
@@ -188,21 +182,21 @@ class TestSSL(IntegrationTest):
             self.assertRaises(
                 ConfigurationError,
                 MongoClient,
-                'server',
+                'localhost',
                 ssl=True,
                 ssl_certfile=CLIENT_ENCRYPTED_PEM,
                 ssl_pem_passphrase="clientpassword",
                 ssl_ca_certs=CA_PEM,
                 serverSelectionTimeoutMS=100)
         else:
-            connected(MongoClient('server',
+            connected(MongoClient('localhost',
                                   ssl=True,
                                   ssl_certfile=CLIENT_ENCRYPTED_PEM,
                                   ssl_pem_passphrase="clientpassword",
                                   ssl_ca_certs=CA_PEM,
                                   serverSelectionTimeoutMS=100))
 
-            uri_fmt = ("mongodb://server/?ssl=true"
+            uri_fmt = ("mongodb://localhost/?ssl=true"
                        "&ssl_certfile=%s&ssl_pem_passphrase=clientpassword"
                        "&ssl_ca_certs=%s&serverSelectionTimeoutMS=100")
             connected(MongoClient(uri_fmt % (CLIENT_ENCRYPTED_PEM, CA_PEM)))
@@ -231,7 +225,6 @@ class TestSSL(IntegrationTest):
         self.assertClientWorks(client)
 
     @client_context.require_ssl_certfile
-    @client_context.require_server_resolvable
     @client_context.require_no_auth
     def test_cert_ssl_validation(self):
         # Expects the server to be running with server.pem and ca.pem
@@ -239,18 +232,18 @@ class TestSSL(IntegrationTest):
         #   --sslPEMKeyFile=/path/to/pymongo/test/certificates/server.pem
         #   --sslCAFile=/path/to/pymongo/test/certificates/ca.pem
         #
-        client = MongoClient('server',
+        client = MongoClient('localhost',
                              ssl=True,
                              ssl_certfile=CLIENT_PEM,
                              ssl_cert_reqs=ssl.CERT_REQUIRED,
                              ssl_ca_certs=CA_PEM)
         response = client.admin.command('ismaster')
         if 'setName' in response:
-            if response['primary'].split(":")[0] != 'server':
-                raise SkipTest("No hosts in the replicaset for 'server'. "
+            if response['primary'].split(":")[0] != 'localhost':
+                raise SkipTest("No hosts in the replicaset for 'localhost'. "
                                "Cannot validate hostname in the certificate")
 
-            client = MongoClient('server',
+            client = MongoClient('localhost',
                                  replicaSet=response['setName'],
                                  w=len(response['hosts']),
                                  ssl=True,
@@ -260,7 +253,9 @@ class TestSSL(IntegrationTest):
 
         self.assertClientWorks(client)
 
-        if _HAVE_IPADDRESS and socket.gethostbyname('server') == '127.0.0.1':
+        # Python 2.6 often can't read SANs from the peer cert.
+        # http://bugs.python.org/issue13034
+        if HAVE_IPADDRESS and sys.version_info[:2] > (2, 6):
             client = MongoClient('127.0.0.1',
                                  ssl=True,
                                  ssl_certfile=CLIENT_PEM,
@@ -269,7 +264,6 @@ class TestSSL(IntegrationTest):
             self.assertClientWorks(client)
 
     @client_context.require_ssl_certfile
-    @client_context.require_server_resolvable
     @client_context.require_no_auth
     def test_cert_ssl_uri_support(self):
         # Expects the server to be running with server.pem and ca.pem
@@ -277,13 +271,12 @@ class TestSSL(IntegrationTest):
         #   --sslPEMKeyFile=/path/to/pymongo/test/certificates/server.pem
         #   --sslCAFile=/path/to/pymongo/test/certificates/ca.pem
         #
-        uri_fmt = ("mongodb://server/?ssl=true&ssl_certfile=%s&ssl_cert_reqs"
+        uri_fmt = ("mongodb://localhost/?ssl=true&ssl_certfile=%s&ssl_cert_reqs"
                    "=%s&ssl_ca_certs=%s&ssl_match_hostname=true")
         client = MongoClient(uri_fmt % (CLIENT_PEM, 'CERT_REQUIRED', CA_PEM))
         self.assertClientWorks(client)
 
     @client_context.require_ssl_certfile
-    @client_context.require_server_resolvable
     @client_context.require_no_auth
     def test_cert_ssl_validation_optional(self):
         # Expects the server to be running with server.pem and ca.pem
@@ -291,7 +284,7 @@ class TestSSL(IntegrationTest):
         #   --sslPEMKeyFile=/path/to/pymongo/test/certificates/server.pem
         #   --sslCAFile=/path/to/pymongo/test/certificates/ca.pem
         #
-        client = MongoClient('server',
+        client = MongoClient('localhost',
                              ssl=True,
                              ssl_certfile=CLIENT_PEM,
                              ssl_cert_reqs=ssl.CERT_OPTIONAL,
@@ -299,11 +292,11 @@ class TestSSL(IntegrationTest):
 
         response = client.admin.command('ismaster')
         if 'setName' in response:
-            if response['primary'].split(":")[0] != 'server':
-                raise SkipTest("No hosts in the replicaset for 'server'. "
+            if response['primary'].split(":")[0] != 'localhost':
+                raise SkipTest("No hosts in the replicaset for 'localhost'. "
                                "Cannot validate hostname in the certificate")
 
-            client = MongoClient('server',
+            client = MongoClient('localhost',
                                  replicaSet=response['setName'],
                                  w=len(response['hosts']),
                                  ssl=True,
@@ -314,6 +307,7 @@ class TestSSL(IntegrationTest):
         self.assertClientWorks(client)
 
     @client_context.require_ssl_certfile
+    @client_context.require_server_resolvable
     def test_cert_ssl_validation_hostname_matching(self):
         # Expects the server to be running with server.pem and ca.pem
         #
@@ -323,14 +317,14 @@ class TestSSL(IntegrationTest):
         response = self.client.admin.command('ismaster')
 
         with self.assertRaises(ConnectionFailure):
-            connected(MongoClient(client_context.pair,
+            connected(MongoClient('server',
                                   ssl=True,
                                   ssl_certfile=CLIENT_PEM,
                                   ssl_cert_reqs=ssl.CERT_REQUIRED,
                                   ssl_ca_certs=CA_PEM,
                                   serverSelectionTimeoutMS=100))
 
-        connected(MongoClient(client_context.pair,
+        connected(MongoClient('server',
                               ssl=True,
                               ssl_certfile=CLIENT_PEM,
                               ssl_cert_reqs=ssl.CERT_REQUIRED,
@@ -340,7 +334,7 @@ class TestSSL(IntegrationTest):
 
         if 'setName' in response:
             with self.assertRaises(ConnectionFailure):
-                connected(MongoClient(client_context.pair,
+                connected(MongoClient('server',
                                       replicaSet=response['setName'],
                                       ssl=True,
                                       ssl_certfile=CLIENT_PEM,
@@ -348,7 +342,7 @@ class TestSSL(IntegrationTest):
                                       ssl_ca_certs=CA_PEM,
                                       serverSelectionTimeoutMS=100))
 
-            connected(MongoClient(client_context.pair,
+            connected(MongoClient('server',
                                   replicaSet=response['setName'],
                                   ssl=True,
                                   ssl_certfile=CLIENT_PEM,
@@ -358,35 +352,34 @@ class TestSSL(IntegrationTest):
                                   serverSelectionTimeoutMS=100))
 
     @client_context.require_ssl_certfile
-    @client_context.require_server_resolvable
     def test_ssl_crlfile_support(self):
         if not hasattr(ssl, 'VERIFY_CRL_CHECK_LEAF'):
             self.assertRaises(
                 ConfigurationError,
                 MongoClient,
-                'server',
+                'localhost',
                 ssl=True,
                 ssl_ca_certs=CA_PEM,
                 ssl_crlfile=CRL_PEM,
                 serverSelectionTimeoutMS=100)
         else:
-            connected(MongoClient('server',
+            connected(MongoClient('localhost',
                                   ssl=True,
                                   ssl_ca_certs=CA_PEM,
                                   serverSelectionTimeoutMS=100))
 
             with self.assertRaises(ConnectionFailure):
-                connected(MongoClient('server',
+                connected(MongoClient('localhost',
                                       ssl=True,
                                       ssl_ca_certs=CA_PEM,
                                       ssl_crlfile=CRL_PEM,
                                       serverSelectionTimeoutMS=100))
 
-            uri_fmt = ("mongodb://server/?ssl=true&"
+            uri_fmt = ("mongodb://localhost/?ssl=true&"
                        "ssl_ca_certs=%s&serverSelectionTimeoutMS=100")
             connected(MongoClient(uri_fmt % (CA_PEM,)))
 
-            uri_fmt = ("mongodb://server/?ssl=true&ssl_crlfile=%s"
+            uri_fmt = ("mongodb://localhost/?ssl=true&ssl_crlfile=%s"
                        "&ssl_ca_certs=%s&serverSelectionTimeoutMS=100")
             with self.assertRaises(ConnectionFailure):
                 connected(MongoClient(uri_fmt % (CRL_PEM, CA_PEM)))
@@ -411,25 +404,25 @@ class TestSSL(IntegrationTest):
         try:
             with self.assertRaises(ConnectionFailure):
                 # Server cert is verified but hostname matching fails
-                connected(MongoClient(client_context.pair,
+                connected(MongoClient('server',
                                       ssl=True,
                                       serverSelectionTimeoutMS=100))
 
             # Server cert is verified. Disable hostname matching.
-            connected(MongoClient(client_context.pair,
+            connected(MongoClient('server',
                                   ssl=True,
                                   ssl_match_hostname=False,
                                   serverSelectionTimeoutMS=100))
 
             # Server cert and hostname are verified.
-            connected(MongoClient('server',
+            connected(MongoClient('localhost',
                                   ssl=True,
                                   serverSelectionTimeoutMS=100))
 
             # Server cert and hostname are verified.
             connected(
                 MongoClient(
-                    'mongodb://server/?ssl=true&serverSelectionTimeoutMS=100'))
+                    'mongodb://localhost/?ssl=true&serverSelectionTimeoutMS=100'))
         finally:
             os.environ.pop('SSL_CERT_FILE')
 
@@ -514,28 +507,28 @@ class TestSSL(IntegrationTest):
             {'role': 'readWriteAnyDatabase', 'db': 'admin'},
             {'role': 'userAdminAnyDatabase', 'db': 'admin'}])
 
-        ssl_client.admin.logout()
+        noauth = MongoClient(
+            client_context.pair,
+            ssl=True,
+            ssl_cert_reqs=ssl.CERT_NONE,
+            ssl_certfile=CLIENT_PEM)
 
-        coll = ssl_client.pymongo_test.test
-        self.assertRaises(OperationFailure, coll.count)
+        self.assertRaises(OperationFailure, noauth.pymongo_test.test.count)
+
+        auth = MongoClient(
+            client_context.pair,
+            authMechanism='MONGODB-X509',
+            ssl=True,
+            ssl_cert_reqs=ssl.CERT_NONE,
+            ssl_certfile=CLIENT_PEM)
 
         if client_context.version.at_least(3, 3, 12):
-            self.assertTrue(
-                ssl_client.admin.authenticate(mechanism='MONGODB-X509'))
             # No error
-            coll.find_one()
-            # MONGODB_X509_USERNAME and None aren't the same user, so we
-            # have to log out before continuing.
-            ssl_client.admin.logout()
+            auth.pymongo_test.test.find_one()
         else:
             # Should require a username
             with self.assertRaises(ConfigurationError):
-                ssl_client.admin.authenticate(mechanism='MONGODB-X509')
-
-        self.assertTrue(ssl_client.admin.authenticate(
-            MONGODB_X509_USERNAME, mechanism='MONGODB-X509'))
-        # No error
-        coll.find_one()
+                auth.pymongo_test.test.find_one()
 
         uri = ('mongodb://%s@%s:%d/?authMechanism='
                'MONGODB-X509' % (
@@ -567,12 +560,20 @@ class TestSSL(IntegrationTest):
 
         bad_client = MongoClient(
             uri, ssl=True, ssl_cert_reqs="CERT_NONE", ssl_certfile=CLIENT_PEM)
+
         with self.assertRaises(OperationFailure):
             bad_client.pymongo_test.test.find_one()
 
-        self.assertRaises(OperationFailure, ssl_client.admin.authenticate,
-                          "not the username",
-                          mechanism="MONGODB-X509")
+        bad_client = MongoClient(
+                client_context.pair,
+                username="not the username",
+                authMechanism='MONGODB-X509',
+                ssl=True,
+                ssl_cert_reqs=ssl.CERT_NONE,
+                ssl_certfile=CLIENT_PEM)
+
+        with self.assertRaises(OperationFailure):
+            bad_client.pymongo_test.test.find_one()
 
         # Invalid certificate (using CA certificate as client certificate)
         uri = ('mongodb://%s@%s:%d/?authMechanism='
